#!/bin/bash -e

echo "================= Adding some global settings ==================="
mkdir -p "$HOME/.ssh/"
mv /c7/config "$HOME/.ssh/"
cat /c7/90forceyes >> /etc/yum.conf
touch "$HOME/.ssh/known_hosts"
mkdir -p /etc/drydock

echo "================= Installing basic packages ================"

yum -y install  \
  sudo \
  wget \
  unzip \
  curl \
  openssl \
  which

sudo yum install epel-release -y

echo "================= Installing Python packages ==================="
sudo yum install -y epel-release
sudo yum install -y \
  python3-devel \
  python-pip

sudo pip2 install --upgrade "pip < 21.0"

sudo pip2 install virtualenv==20.0.5
sudo pip2 install pyOpenSSL==19.1.0

export NODE_VERSION=v14.19.0
echo "================= Installing nodejs $NODE_VERSION ================="
wget https://nodejs.org/dist/$NODE_VERSION/node-$NODE_VERSION-linux-x64.tar.xz
tar -xf node-$NODE_VERSION-linux-x64.tar.xz
cp -Rf node-$NODE_VERSION-linux-x64/{bin,include,lib,share} /usr/local
/usr/local/bin/node -v
rm -rf node-$NODE_VERSION-linux-x64.tar.xz

export DOCKER_VERSION=18.09.9
echo "================= Installing Docker $DOCKER_VERSION ================="
wget https://download.docker.com/linux/static/stable/x86_64/docker-$DOCKER_VERSION.tgz
tar -xzf docker-$DOCKER_VERSION.tgz -C /opt
rm -rf docker-$DOCKER_VERSION.tgz
ln -s /opt/docker/docker /usr/bin/docker

export JQ_VERSION=1.6*
echo "================= Adding JQ $JQ_VERSION ==================="
sudo yum install -y jq-"$JQ_VERSION"

echo "================= Installing CLIs packages ======================"

export GIT_VERSION=2.22.0
echo "================= Installing Git $GIT_VERSION ===================="
sudo yum install -y http://opensource.wandisco.com/centos/7/git/x86_64/wandisco-git-release-7-2.noarch.rpm
sudo yum install -y git-"$GIT_VERSION"

export GCLOUD_SDKREPO=298.0*
echo "================= Adding gcloud $GCLOUD_SDKREPO  ============"
sudo tee -a /etc/yum.repos.d/google-cloud-sdk.repo << EOM
[google-cloud-sdk]
name=Google Cloud SDK
baseurl=https://packages.cloud.google.com/yum/repos/cloud-sdk-el7-x86_64
enabled=1
gpgcheck=0
repo_gpgcheck=0
gpgkey=https://packages.cloud.google.com/yum/doc/yum-key.gpg
       https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
EOM
#adding key required to install gcloud
sudo rpm --import  https://packages.cloud.google.com/yum/doc/yum-key.gpg
sudo rpm --import  https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
sudo yum install -y google-cloud-sdk-"$GCLOUD_SDKREPO"

export AWS_VERSION=1.16.309
echo "================= Adding awscli $AWS_VERSION ===================="
sudo pip install awscli=="$AWS_VERSION"

AZURE_CLI_VERSION=2.0*
echo "================ Adding azure-cli $AZURE_CLI_VERSION  =============="
sudo rpm --import https://packages.microsoft.com/keys/microsoft.asc
sudo sh -c 'echo -e "[azure-cli]\nname=Azure CLI\nbaseurl=https://packages.microsoft.com/yumrepos/azure-cli\nenabled=1\ngpgcheck=1\ngpgkey=https://packages.microsoft.com/keys/microsoft.asc" > /etc/yum.repos.d/azure-cli.repo'
sudo yum install -y azure-cli-$AZURE_CLI_VERSION

export JFROG_VERSION=1.53.1
echo "================= Adding jfrog-cli $JFROG_VERSION==================="
wget -nv https://releases.jfrog.io/artifactory/jfrog-cli/v1/"$JFROG_VERSION"/jfrog-cli-linux-amd64/jfrog?bt_package=jfrog-cli-linux-amd64 -O jfrog
sudo chmod +x jfrog
mkdir -p /jfrog-init/jfrog
sudo cp jfrog /jfrog-init/jfrog/jfrog
sudo mv jfrog /usr/bin/jfrog

export JFROG_2_VERSION=2.15.0
echo "================= Adding jfrog-cli $JFROG_2_VERSION==================="
wget -nv https://releases.jfrog.io/artifactory/jfrog-cli/v2-jf/"$JFROG_2_VERSION"/jfrog-cli-linux-amd64/jf -L -O jf
sudo chmod +x jf
mkdir -p /jfrog-init/jfrog2
sudo mv jf /jfrog-init/jfrog2/jf
sudo ln -s /jfrog-init/jfrog2/jf /jfrog-init/jfrog2/jfrog

HELM_VERSION=2.16.1
echo "================= Adding helm cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-amd64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-amd64/helm
chmod +x ./linux-amd64/tiller
sudo mv ./linux-amd64/helm /usr/local/bin/helm
sudo mv ./linux-amd64/tiller /usr/local/bin/tiller
rm -fr ./linux-amd64
rm -f helm.tar.gz

HELM_VERSION=3.7.2
echo "================= helm3 cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-amd64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-amd64/helm
sudo mv ./linux-amd64/helm /usr/local/bin/helm3
rm -fr ./linux-amd64
rm -f helm.tar.gz
